<?php

namespace Drupal\google_photos_api\Service;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\google_api_client\Service\GoogleApiClientService;

/**
 * Class Google Photos API Client Service.
 *
 * @package Drupal\google_photos_api\Service
 */
class GooglePhotosClient {

  /**
   * Uneditable Config.
   *
   * @var \Drupal\Core\Config\Config|\Drupal\Core\Config\ImmutableConfig
   */
  private $config;

  /**
   * The logger factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactoryInterface
   */
  public $loggerFactory;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Google API Client.
   *
   * @var \Drupal\google_api_client\Service\GoogleApiClientService
   */
  private $googleApiClient;

  /**
   * Google Service Photos Library.
   *
   * @var \Google_Service_PhotosLibrary
   */
  public $googleServicePhotosLibrary;

  /**
   * Callback Controller constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactory $config
   *   An instance of ConfigFactory.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $loggerFactory
   *   LoggerChannelFactoryInterface.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param \Drupal\google_api_client\Service\GoogleApiClientService $googleApiClient
   *   GoogleApiClient.
   */
  public function __construct(ConfigFactory $config,
                              LoggerChannelFactoryInterface $loggerFactory,
                              EntityTypeManagerInterface $entityTypeManager,
                              GoogleApiClientService $googleApiClient) {
    $this->config = $config->get('google_photos_api.settings');

    $this->loggerFactory = $loggerFactory;
    $this->entityTypeManager = $entityTypeManager;

    $this->googleApiClient = $googleApiClient;
    $google_api_client_id = $this->config->get('google_api_client_id');
    if ($google_api_client_id) {
      $google_api_client = $this->entityTypeManager->getStorage('google_api_client')->load($google_api_client_id);
      $this->googleApiClient->setGoogleApiClient($google_api_client);
      $this->googleServicePhotosLibrary = $this->getGoogleServicePhotosLibrary();
    }
  }

  /**
   * Helper method to getGoogleMyBusinessClient.
   *
   * @return \Google_Service_PhotosLibrary
   *   Google Service Photos Library.
   */
  private function getGoogleServicePhotosLibrary() {
    // Set up the Photos Library Client that interacts with the API.
    $googleServicePhotosLibrary = new \Google_Service_PhotosLibrary($this->googleApiClient->googleClient);
    return $googleServicePhotosLibrary;
  }

}
